@@ -17,10 +17,31 @@ def cron_validator(value):
 
 
 class CrontabBaseQuerySet(models.QuerySet):
-
     def enabled(self):
         return self.filter(is_enabled=True)
 
+    @staticmethod
+    def now():
+        """
+        We have a fiddly requirement for `now`.
+
+        `croniter` has issues if you pass it the current time in UTC, and will
+        give you have a datetime with UTC timezone, but adjusted to system
+        local timezone.
+
+        To correct for this, we set the current timezone.
+
+        Additionally, asking for `get_next`, if the current time matches the
+        crontab pattern, `croniter` will return the _next_ time.
+
+        To correct for this, we subtract one second from the time.
+
+        Setting microsecond to 0 is just tidiness.
+        """
+        return timezone.localtime(
+            timezone.now().replace(microsecond=0) - timedelta(seconds=1)
+        )
+
     def scan_jobs(self):
         """
         Convenience function for scanning a set of Jobs exclusively.
@@ -35,13 +56,9 @@ class CrontabBaseQuerySet(models.QuerySet):
         """
         Yield jobs which should be run this minute.
         """
-        now = timezone.now()
+        now = self.now()
 
-        for job in (
-            self.enabled()
-            .filter(last_run__lt=Now() - timedelta(seconds=59))
-            .scan_jobs()
-        ):
+        for job in self.enabled().filter(last_run__lt=Now() - timedelta(seconds=59)).scan_jobs():
             next_run = croniter(job.crontab, now).get_next(datetime)
             if (next_run - now) < timedelta(minutes=1):
                 yield job
@@ -50,7 +67,7 @@ class CrontabBaseQuerySet(models.QuerySet):
         """
         yields jobs whose last run is longer ago than their crontab frequency.
         """
-        now = timezone.now()
+        now = self.now()
 
         for job in self.enabled().scan_jobs():
             next_run = croniter(job.crontab, job.last_run).get_next(datetime)
@@ -59,9 +76,10 @@ class CrontabBaseQuerySet(models.QuerySet):
 
 
 class CrontabBase(models.Model):
-    '''
+    """
     Abstract base model for custom Bronski crontab model.
-    '''
+    """
+
     crontab = models.CharField(max_length=100, validators=[cron_validator])
     function = models.CharField(max_length=255)
     kwargs = JSONField(default=dict, blank=True)
@@ -74,7 +92,7 @@ class CrontabBase(models.Model):
         abstract = True
 
     def __str__(self):
-        return f'{self.function} @ {self.crontab}'
+        return f"{self.function} @ {self.crontab}"
 
     def get_function(self):
         """Helper to import the named function in `function`."""
